﻿#
# IMPORTANT: There are issues when dot sourcing (including) more than 1 level of script files
#			 So all common functions has to go here
#			 Functions may be split into multiple files, but only at one level
#

<#
# Connects to a VMM server
# Uses script variables, instead of params
#>
function VConnect-Connect-VMMServer {
	if($ServerCred)
	{
		# Connect to the VMM server using $VIServerCred
		$private:connection = Get-SCVMMServer -ComputerName $VMMStampName -Credential $ServerCred    
	}
	else
	{
		$private:vmmPasswordSecure = $VmmStampPassword | ConvertTo-SecureString -AsPlainText -Force
		$private:cred = New-Object System.Management.Automation.PSCredential($VmmStampUserName, $private:vmmPasswordSecure)
		# Connect to the VMM server using above credentials
		$private:connection = Get-SCVMMServer -ComputerName $VMMStampName -Credential $private:cred    
	}
    return $private:connection
}

<#
# Connects to a VMM server For Behalf of the User
# Uses script variables, instead of params
#>
function VConnect-Connect-VMMServer-ForOnBehalfOf {
    if($ServerCred)
    {
        # Connect to the VMM server using $VIServerCred
        $private:connection = Get-SCVMMServer -ComputerName $VMMStampName -Credential $ServerCred -ForOnBehalfOf    
    }
	else
	{
        $private:vmmPasswordSecure = $VmmStampPassword | ConvertTo-SecureString -AsPlainText -Force
        $private:cred = New-Object System.Management.Automation.PSCredential($VmmStampUserName, $private:vmmPasswordSecure)
        # Connect to the VMM server using above credentials
        $private:connection = Get-SCVMMServer -ComputerName $VMMStampName -Credential $private:cred -ForOnBehalfOf
	}
    return $private:connection
}

function Get-UserRole {
param([string] $userEmailId)
    if ($userEmailId -eq $null) 
	{
		$errorMessage = "User Id is Empty"
		return Get-ScriptErrorResult $errorMessage 
	}
    if($userEmailId.Length -ge 27)
	{
        $maxLength =  27 ;
    }
    else
    {
        $maxLength  = $userEmailId.Length;
    }
    $userId = $userEmailId.Substring(0, $maxLength);
    return $userId;
}

function Get-VConnect-NetworkName {
param([string] $subscriptionId,
      [string] $networkName)
	return "{0}:{1}" -f $subscriptionid, $networkName;
}

function Get-VConnect-SubnetName {
param([string] $subscriptionId,
      [string] $subnetName)
	return "{0}:{1}" -f $subscriptionId, $subnetName;
}

function Get-VConnect-UserRoleId {
param([string] $subscriptionId,
	[string] $userEmailId)
	$userName = Get-UserRole $userEmailId;
	return "{0}_{1}" -f $userName, $subscriptionId;
}

function Get-VConnect-EndingIp {
param([string] $startingIp,
      [string] $numIps)
      $option = [System.StringSplitOptions]::RemoveEmptyEntries
      $startIpSplit = $startingIp.Trim().Split("{ '.' }", $option);
      [int] $numberOfIps = $numIps -as [int];
      [int] $endIpSplit = $startIpSplit[3] -as [int];
      $endIpSplit = $endIpSplit + $numberOfIps;
      return "{0}.{1}.{2}.{3}" -f $startIpSplit[0], $startIpSplit[1], $startIpSplit[2], $endIpSplit
}

function Get-VConnect-NATName {
param([string] $networkName)
	return "{0}_NatConnection" -f $networkName
}

function Get-ScriptResult { 
param([bool] $isSuccess,
      [int] $errorCode,
      [string] $message,
      [PSObject] $details)
    
    if($details -ne $null) 
    {
        $detailsJson = ConvertTo-Json -InputObject $details -Compress
    }

    $result = @{ 
                    IsSuccess = $isSuccess
                    Message = $message
                    ErrorCode = $errorCode
                    Exception = ""
                    Details = $details
                    DetailsJson = $detailsJson
                }  
    return New-Object PSObject -Property $result
}

function Get-ScriptErrorResult { 
param([string] $message,
      [string] $exception)
    
    $resultOb = Get-ScriptResult $false -1 $message $null
    $resultOb.Exception = $exception
    return $resultOb
}

function Get-FullLastError {
    return ($error[0] | out-string)
}